class Theme:
    panel_title = "default"
    heading = "bold yellow"
    table_field = "bold bright_magenta"
    table_value = "none"
    popularity_source = "bright_cyan"
    inline_stat = "cyan"
    vendor_list = "cyan"
    nameserver_list = "bright_blue"
    disclaimer = "italic white on red"
    tags = "bright_white on black"
    product = "orange_red1"
    port = "bright_cyan"
    transport = "cyan"
    footer = "cyan"
    info = "bold green"
    warn = "bold yellow"
    error = "bold red"
    timestamp_date = "not bold default"
    timestamp_t = "dim bright_white"
    timestamp_time = "dim default"
    timestamp_z = "dim bright_white"
    asn_org = "bright_white"
    whois_org = "bright_cyan"
